
# q-expansion of newform 6003.2.a.n, downloaded from the LMFDB on 12 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6003
weight = 2
poly_data = [-5, 37, 9, -215, 13, 342, -77, -188, 54, 41, -13, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-20718, 158295, -31183, -433403, 194815, 277030, -131017, -62480, 30343, 4126, -2268, 69], 6469], [[-29932, 117880, 49707, -328362, 24036, 209382, -30082, -51132, 7810, 4875, -607, -127], 6469], [[-25638, 84019, 135717, -276488, -84627, 210856, 13625, -63527, 773, 8049, -210, -353], 6469], [[34852, -75949, -216607, 177916, 255406, -143208, -114560, 52179, 21760, -8798, -1451, 549], 6469], [[23075, -19087, 34877, 86000, -218601, 1464, 154428, -32306, -37175, 10271, 2852, -874], 6469], [[10438, -43159, -153652, 156809, 282647, -182412, -163016, 84275, 36674, -16651, -2741, 1153], 6469], [[-21970, 64932, 177063, -190488, -303228, 212320, 168053, -95833, -36402, 18320, 2642, -1227], 6469], [[-10451, -43380, -89336, 89329, 291927, -130539, -190180, 73554, 44255, -16487, -3336, 1231], 6469], [[8869, 63686, -238564, -88693, 605079, -103569, -383278, 106697, 88739, -28263, -6684, 2257], 6469], [[-20106, -161659, 391735, 441457, -926609, -126167, 578643, -63186, -134015, 28520, 10130, -2687], 6469]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], [-1, 1, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0], [1, 0, 1, 0, 0, -1, 0, 0, 0, 0, -1, 0], [-2, 1, 0, 1, 0, 0, 1, 0, 0, 2, -1, -1], [2, 0, 0, 1, 0, -1, 1, 1, 0, 0, 0, 0], [-1, 1, 1, 1, 2, 2, 1, 1, 0, 0, 1, 1], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, -1, 0, -1, 0, -2, -1, 0, 0, -2, 0], [-1, 1, -1, 1, 0, 0, 1, -1, -2, 2, -3, -2], [0, -2, 0, -1, -3, -3, -4, -1, 0, -1, -1, -2], [5, -1, 1, 0, -2, 0, 0, -1, 0, -1, 0, 2], [5, 0, 1, 0, -1, -1, -2, -2, 0, 0, 0, 0], [-1, 4, 1, -2, 0, 0, 2, 1, 0, 1, -2, 1], [1, 2, 0, 0, -2, -2, 1, 1, 0, 0, -1, 1], [-3, 0, -1, 1, 5, 5, 2, 0, -2, -1, 2, 2], [-3, 2, -1, 2, 3, 0, 4, 0, -1, 2, 1, 0], [2, -3, 0, -2, -4, -4, -4, -2, 1, 1, -3, -3], [1, 1, 0, -2, -1, -1, 0, -2, -2, 0, -3, -2], [-1, 2, -2, 1, 1, 2, -1, 3, 1, -2, 1, -2], [3, -3, -1, 0, -3, 0, -4, 0, 0, -1, -2, -2], [-2, 0, -1, 0, 2, 1, 1, 1, 2, -3, 1, 1], [5, -1, 0, -2, -2, 0, -4, -1, 1, -1, 0, -1], [-2, 1, 2, -2, 2, 1, 2, 1, -1, -1, 1, 5], [0, 1, 1, 1, -2, 0, 3, -4, -2, 4, -4, -2], [-2, 1, 1, 1, 2, 0, 2, 2, -1, -1, 0, 1], [4, -2, 1, 0, -2, 0, 0, 0, -2, 1, 1, 0], [0, 3, 0, 1, -2, 2, 1, 1, -2, 2, -2, -2], [-4, -1, -1, -2, -2, -1, 1, -1, 0, 0, -2, -2], [1, -1, 3, -3, 0, -1, -1, -2, 2, 2, 1, 3], [3, 1, 3, -3, 2, -1, 0, -2, -1, 0, 1, 2], [1, -2, -1, 0, 0, 2, 4, -2, -2, 5, -3, -2], [5, -4, 0, -1, -3, 0, -3, 0, 1, -3, 2, 2], [-3, -2, 0, -1, 2, 4, 1, 0, -3, 1, 2, 1], [4, 1, 2, -2, -4, -5, -2, 0, 2, 1, 1, 1], [6, -1, 1, 1, -2, -1, -1, 1, 0, -4, 2, 1], [4, 1, -4, 2, 5, 4, 1, 1, -2, 0, 0, -1], [-2, -4, -1, 1, 3, 4, 4, -1, -5, -2, -2, 1], [-3, -3, 2, -3, -7, -7, -7, -4, 0, 2, -2, -3], [1, -1, 0, 1, 3, -2, 0, 3, -1, -1, 2, 0], [1, 2, -2, 2, 4, 3, 7, 0, -4, 2, 1, 1], [5, -3, 1, -2, -3, -3, -3, -3, -4, -1, -2, -5], [1, -2, 2, 0, -5, -2, -2, -4, -5, 3, -6, -5], [2, -4, -6, 3, 3, 4, -2, 2, -1, -1, 3, -2], [0, -4, -2, -4, 0, -4, -7, -1, 3, -3, -1, -1], [10, -3, 4, 0, -1, -2, 2, -4, -7, -1, -3, 1], [-3, 0, 2, 3, 2, 2, 1, -3, -2, 2, 1, -1], [6, -1, 5, -2, -6, -2, -1, -1, -1, 0, -3, -1], [0, -1, 0, 3, 4, 2, 0, 1, 0, 0, 0, 3], [-5, -1, -5, 0, 0, 1, -2, -3, -3, -2, 0, -5], [7, 1, 4, -2, 1, -3, -1, -3, -3, 1, -2, 3], [4, 5, 1, -5, -3, -2, -5, -1, 1, 2, -3, 0], [-6, 1, 4, 1, 4, 2, 1, 0, 2, 2, 2, 0], [5, -1, -6, -2, 0, 0, -7, -5, -2, -5, 0, -3], [-3, 4, -1, 1, -8, -5, -1, 0, 3, 4, -7, -4], [1, -6, -1, 4, 2, 0, 2, -1, -3, 1, -2, -2], [-1, 5, 3, 1, -1, 0, 2, 1, 2, 1, -1, 2], [-3, -7, -4, 1, 1, 1, -4, -6, -7, -3, 0, -5], [6, -3, 4, 1, 5, 5, 5, -2, 0, 2, 2, 6], [-3, 4, 0, 6, 7, 1, 9, 2, -1, 5, 0, 1], [7, -6, -3, 0, -7, -6, -7, -7, -4, -3, -4, -8], [2, -3, 2, -3, 3, 4, -3, 0, -1, 0, 3, 2], [9, -3, 3, -1, -1, -2, 6, 0, 2, 1, 0, 3], [12, -1, 2, 3, 0, 4, 2, -2, -4, -6, 0, 4], [3, -1, 1, -3, -2, 2, -3, -6, -1, 1, -2, -5], [7, -2, 3, -5, -6, -4, -9, -6, 1, -2, -1, -6], [2, -8, 0, -4, -4, -4, -6, -3, -3, -6, -1, 0], [4, -6, -1, 2, 7, 4, 2, 5, -3, -6, 8, 2], [-8, -4, -3, 4, 4, 2, 2, 0, -1, 0, 0, -1], [-6, -1, 5, -3, -3, 2, 1, -2, 3, 0, -4, 3], [-3, 2, 2, 5, 5, 8, 8, 0, 0, -2, 4, 5], [5, 2, -3, -1, -5, -4, -2, -2, 3, 0, -3, -5], [0, -2, -4, 7, 8, 4, -2, 0, -4, -2, 4, 1], [11, -1, -3, 3, 5, 2, 0, 7, 6, -4, 9, 1], [0, -2, -5, 2, 5, 1, -6, 2, -1, -3, 6, -3], [-3, 5, -7, 0, 6, 6, 1, -2, -4, 0, 2, 1], [4, 10, -2, 1, 3, 3, 5, 0, -5, 1, -3, 1], [0, 1, -4, 3, 2, 4, -1, 4, 5, -5, 5, 4], [-1, 0, -2, -2, 0, 1, 1, 1, -2, -1, -2, -1], [-2, -1, 5, -7, -9, -3, -6, -7, -3, -2, -8, -1], [0, 0, -4, 4, 3, 6, 3, 1, 0, -3, 1, 3], [0, 3, 0, 6, 1, 6, 0, -1, -2, 2, 0, -3], [-12, 8, -3, 0, 6, 7, 8, 4, -1, 2, 2, 6], [-6, -2, 2, -5, 3, 7, 1, 0, 4, 1, -1, 4], [5, -6, 1, 1, -1, -1, -1, 2, 5, -3, 8, 4], [1, 4, 1, 5, -2, -5, 2, -1, -3, 2, -3, -5], [1, 1, 3, -3, 2, -4, 3, -4, 5, 3, -4, 0], [3, -5, -1, -1, -3, -2, 2, -2, 5, -2, -3, -1], [-17, 5, -3, -5, 1, 0, -1, 2, -2, -2, 3, 4], [5, -2, 1, 3, 7, -1, 7, 3, -8, 6, 1, -3], [-7, 1, -8, 0, -3, 5, -2, -4, 4, 2, -5, -7], [4, 1, -7, -4, -2, 1, -4, -3, -1, -2, 0, -3], [1, 5, -5, 5, 11, 8, 8, 1, -1, 3, 2, -2], [-6, 10, -4, 5, 6, 7, 8, 6, 5, 2, 3, 1], [11, -5, 8, 3, 0, -2, -2, -1, 4, 4, 4, 3], [2, -4, 3, -2, -4, -6, -4, 7, 7, -4, 2, 4], [9, -6, -5, 3, 2, -2, -5, 7, -4, -7, 6, -4], [-1, -2, -1, 1, -4, 0, 3, 3, 7, 1, 2, -3], [6, 2, -8, 1, 11, 2, 0, 6, -5, -8, 6, -1], [8, -4, 1, -1, -1, 4, 4, 2, -3, -4, 4, 6], [1, 3, -5, 6, 4, 3, 2, -3, -9, -1, 2, -5], [4, -3, 2, 2, 2, 2, 2, -7, -8, 6, -6, -3], [-3, -3, 6, 2, -1, 2, 1, 2, 8, 2, 5, 6], [5, -6, 4, -2, -1, 0, 0, -7, 3, 2, -3, 3], [8, -12, -4, 4, 1, 1, -1, 3, 8, -1, 4, 5], [-4, -1, -2, 0, 5, -1, -8, 4, 0, -3, 5, 3], [11, -8, 3, -3, -7, -7, -2, -2, -1, 9, -6, -3], [9, -7, -2, 1, -2, 0, -5, -3, -4, 0, 1, -8], [-10, 7, -4, 4, 3, 6, 9, -3, -3, 5, -6, -4], [-6, 7, -3, 0, -5, -13, -5, 1, 2, -2, 0, -4], [-7, -15, 1, 0, -2, 1, -4, -4, 1, -1, 2, 5], [1, 3, -4, 1, 3, -2, 0, -2, -1, 4, -1, 1], [6, -4, 2, -3, -2, -3, -8, 0, -1, -5, 5, 1], [1, 0, -4, 7, 7, -1, 5, 3, -3, -3, -4, -3], [-11, 9, -3, -3, 0, -8, -5, 1, 2, 2, 1, -3], [-3, 1, -4, 2, -3, 1, -1, -3, -5, 4, 1, -4], [-5, -9, 5, -2, -6, 3, -5, 4, 5, 1, 2, 4], [5, -8, -7, 0, -1, -6, -1, 2, 8, -4, 5, -2], [-2, 1, 3, 10, 0, 3, 2, -3, -7, 11, -4, -5], [10, 6, 8, -7, -8, -9, -5, 0, 4, -1, -3, 2], [1, -11, 4, 4, -2, -5, 0, 0, 9, 3, 0, -2], [-3, -1, 7, -4, -8, 0, -8, -5, 2, 4, -3, 0], [9, -6, 4, -1, -2, 4, -6, 0, 3, 4, 2, 2], [-10, 1, -1, -3, 3, 1, 5, 10, 6, -2, 5, 1], [3, -9, 2, -5, -10, -10, -8, -5, 3, -3, -4, -2], [12, -4, -4, 4, -5, -4, -1, -1, -5, 1, -9, -2], [-5, 0, -3, 2, -5, -1, 1, -3, 2, 6, -7, -12], [7, -4, 2, 0, 8, 7, 3, 8, 7, -5, 10, 11], [-5, -2, -1, 2, 7, 5, -5, 5, 3, -4, 3, 8], [-13, -2, 4, 3, 5, 5, 3, -1, -6, 5, -2, 4], [5, 1, 9, -8, -4, -6, 2, -1, 8, 0, 1, 11], [10, 0, 6, 2, -5, -1, 1, 1, 2, 6, -6, 0], [5, 1, 4, 3, 15, 4, 11, 3, -6, 5, 0, 5], [12, -4, -7, -9, -12, -13, -18, -3, 4, 1, -5, -5], [-8, 9, 2, -5, 1, -5, -2, -8, -6, -2, -8, -1], [11, 6, 2, 2, -1, 9, 6, -1, -5, 5, -4, -1], [-3, -1, 5, -5, 5, -1, -2, -1, -2, 1, 6, 3], [0, 1, 0, -1, -2, -5, 2, -1, -3, -5, 3, 4], [7, -5, 0, -3, -11, 0, -2, 2, 6, 1, -3, 5], [-8, 2, -5, 2, -4, 4, 1, -1, 5, 6, -8, -3], [-1, 3, -5, 4, -2, -2, -5, 9, 3, -11, 2, -3], [3, -4, -3, 7, 8, 11, -4, -1, 4, 2, 9, 2], [10, 6, -1, 6, 4, 3, 8, 5, 3, 2, -2, 1], [-4, 1, 4, 2, 10, 2, 1, 9, 5, -8, 10, 13], [2, -2, -3, -8, -8, -13, -12, -3, -4, 2, -5, -11], [-7, 6, -13, 2, 9, 1, 8, 4, -3, 2, 3, -4], [-11, -1, -7, 4, 15, 13, 6, 8, -5, 0, 7, -3], [6, -3, 6, 2, -3, 0, -11, 2, 4, 8, 5, 1], [8, -3, 7, -7, -4, -4, -7, -2, 6, -6, 0, 4], [-2, 9, -2, 5, -6, -11, 7, 9, 2, 5, -5, 0], [-2, -7, -4, 2, 14, 18, 0, 2, -5, 0, 12, 5], [1, -2, -3, 0, 2, 1, 1, -5, -5, -6, 3, 6], [-10, 2, 2, 10, -9, 1, 3, 3, -4, 5, -5, -2], [-23, 7, -8, -3, 3, 0, 3, 9, 2, -3, 2, 1], [-5, 4, -10, 2, 12, 11, -3, -1, 0, -3, 10, 3], [-11, 1, -5, 2, -4, -2, 3, -5, -6, 8, -9, -14], [-1, -2, -5, 1, -2, 7, 5, -2, -10, 2, 2, -2], [7, 0, 2, 4, 4, 1, 5, 1, -13, 2, 5, -4], [-2, -5, 0, 0, -1, 1, 1, -2, -8, 1, -6, 3], [-9, 5, -3, -1, -5, -3, -8, 5, 5, -2, 5, 3], [12, 2, 5, 0, -13, -10, 2, -5, 1, 6, -12, -4], [-3, 3, -5, 10, 13, 9, 7, 0, -3, -7, 5, 0], [-4, 2, 2, 0, -7, 7, -6, -6, 2, 6, -4, -5], [-13, 7, 0, 0, 3, 9, 8, -3, -6, 4, -5, -6], [-5, 12, 8, -7, -1, 0, 4, 8, 9, -1, 2, 5], [4, -2, 1, 1, -2, -2, 1, 2, -7, -6, -7, 1], [21, -11, -2, -2, 0, -13, -6, 3, 3, -8, 1, 6], [-2, 2, -12, 2, -2, -1, 5, 4, -1, -3, -3, -5], [9, 4, -1, -4, -1, 0, -3, 1, -3, -8, 4, 4], [2, 7, 1, -1, -6, -2, 4, -4, -2, 0, -12, -3], [10, -8, -8, 10, 0, 8, -10, -6, -14, -2, 0, -11], [-9, 2, -11, 1, -2, 2, -6, -2, -3, 0, 9, -7], [0, -10, -2, 1, 4, 4, -3, -1, 2, -7, 11, 4], [6, 0, 12, 3, -3, 9, 1, 0, 11, 3, 5, 9], [-3, -6, -3, -2, 10, 4, 1, -2, -1, -2, 1, 1], [3, 1, 6, 0, -4, 1, -6, -3, -4, 1, -4, 8], [-7, 4, -3, -3, -2, -5, 1, 5, 8, -4, 3, 7], [-6, 0, -7, -6, -4, -12, -11, 5, 3, -7, 3, -2], [-17, 16, -10, 0, 8, 10, 7, 2, -8, 0, 5, -2], [8, 1, 1, 6, 6, 5, -5, 6, 5, -3, 11, 3], [-8, 6, 2, 2, 16, 12, 10, -1, -3, 6, -5, -1], [6, 5, 9, -8, -3, -5, 1, 2, 9, 1, -5, 4], [1, -4, 2, -2, -3, -6, -3, -5, -6, 3, -3, 0], [-7, 11, -7, -5, 3, 15, -1, 2, -6, -8, 5, 4], [-8, -2, -6, -2, -2, 1, 9, 5, 3, -4, 0, 0], [5, -3, -3, -2, -6, 5, -7, -15, -6, 1, -8, -2], [5, -6, -2, 1, -3, -6, -8, -2, 0, -9, -2, 1], [-4, 4, 2, -2, 2, 7, -4, -9, -14, -1, -6, -4], [-8, 0, -2, -1, -19, -8, -6, -2, 5, 5, -15, -5], [-13, -5, -5, -2, -4, 2, -2, -3, -10, -7, -6, -4], [14, -9, -7, 3, -1, 3, -3, -4, 3, -9, 1, 0], [-13, 6, 5, -2, -2, -13, -2, 3, 1, 10, -5, -6], [21, -7, 5, -6, -1, -5, -12, 4, 6, 0, 1, 5], [5, 1, 7, -3, -8, -8, -11, 1, 5, 6, -7, -7], [5, -20, 6, -2, 2, -3, -15, -6, 8, -12, 13, 8], [6, 2, 1, -4, -6, 11, -3, 1, -3, -2, -11, 2], [0, -4, 3, -7, -18, -13, -5, -4, -4, 2, -20, -3], [5, 1, 2, -10, -18, -9, -1, -4, -2, -5, -10, -2], [9, -4, 1, -4, -15, -12, -10, -13, 0, 9, -12, -9], [0, -2, 4, -13, -11, -3, -6, -4, -2, -9, -5, 1], [10, 2, 1, -5, -6, -8, -7, -4, -1, 5, -3, -4], [2, 7, -4, -4, -7, -1, -6, -4, -6, -4, -2, -5], [20, -6, 5, 2, 3, 7, 7, 4, -1, -7, -2, 3], [-30, 11, 4, 3, -6, -5, 10, -4, 0, 17, -15, -5], [16, -12, 0, -9, -6, -10, -22, -7, 8, -9, 5, 1], [-11, -8, -4, 7, -5, -1, 4, 7, -5, -4, -4, -4], [-2, 17, -2, 0, 3, 13, 10, -2, -3, 3, -11, -5], [4, 2, -1, -6, 14, -1, 2, 5, 8, -7, 7, 6], [9, 11, 2, -4, 4, -2, 6, 4, 1, -4, 1, 8], [10, -6, -4, 8, 11, 1, 9, 14, -2, -12, 14, 8], [8, -11, -4, -4, -8, -3, -23, -13, 5, -6, 4, -5], [6, 8, -5, -2, -4, -2, 0, 4, 7, -3, 3, -3], [-12, 8, 6, -1, 13, 9, 6, -3, -4, 9, 0, 1], [1, 8, 8, -8, -10, -15, -1, -1, 2, 3, -10, -5], [11, -1, -3, -1, 14, 5, 2, 2, 4, -2, 9, -3], [-7, 2, 11, 2, 3, 6, 14, 6, -3, 10, 5, 9], [25, -6, 5, 2, -10, -2, -11, 0, 4, -10, -3, -3], [16, 3, 2, 8, 18, 7, 12, 10, 0, 0, 14, 3], [14, -19, 9, 1, -9, -8, -17, -2, 9, -2, 0, -5], [-10, -6, 3, 2, 5, 19, 1, 4, 6, 0, 6, -2], [-1, -6, 1, -4, 4, 1, -5, 2, 4, -6, 9, 3], [1, -6, 9, 3, 0, -12, -3, 1, 5, 3, 4, 1], [9, 4, 3, -2, -5, -8, -2, -4, 6, 0, -7, -1], [-9, -15, 0, -7, -12, -6, -19, -6, 12, 8, -7, -13], [1, -11, 3, 2, -5, -17, -5, 2, 0, -6, 3, -4], [-16, 16, -1, -3, 10, 0, 9, 7, 9, -5, 7, 7], [-9, 0, -7, 1, 0, 6, -6, 0, 8, 2, 7, 1], [-1, 2, 4, 1, 2, -2, 6, 1, -6, 0, -3, -5], [-10, 10, -5, 12, 2, -3, 14, 8, -5, 4, -2, -6], [8, -4, -3, -1, -5, -7, -4, 5, 9, -7, 5, 5], [-25, 7, 0, -3, -10, -5, -2, 9, 16, 12, 1, -3], [0, 7, -9, 4, 7, 5, 4, 7, -10, -8, -4, -3], [-1, -6, -3, -1, 10, 5, 7, 1, -8, 4, 7, 0], [-6, -4, 4, 0, -2, 12, 7, 5, 11, 3, 1, -4], [4, 1, -3, 1, 8, 7, -13, 0, -6, -9, 11, 0], [12, -4, 9, -4, -9, -12, -9, 1, -1, 2, -4, 2], [-4, -3, -7, 3, 5, 2, 3, 4, 5, 9, 3, -2], [4, -3, 6, -1, -9, 4, -10, 2, 11, -8, 6, 6], [4, -2, 3, -4, -4, 1, -1, 0, 3, -10, -8, 7], [13, 7, -4, -4, -7, 7, -5, -5, 2, 8, -1, -5], [16, -3, 8, 10, -1, -6, 1, -12, -7, 7, -9, 1], [-11, -8, -6, 2, 22, 11, -2, -5, -7, -11, 10, 6], [-9, -10, -3, 1, 4, 2, 3, 3, -2, -5, 12, -4], [-6, 1, -4, 3, -10, 4, -3, -4, 0, -1, -1, -8], [-27, -2, -14, 5, 6, 5, -3, -7, -6, 1, 4, -12], [9, -18, 2, -1, 3, -9, -4, 3, -7, -9, 16, 4], [21, -9, 11, 0, 2, -2, -14, 1, 5, 3, 12, 5], [21, -9, -17, 2, 9, 0, -1, -1, -7, -8, 11, -2], [-12, 1, 0, 1, -9, -11, 1, -10, 2, 5, -14, -4], [1, 21, 1, 6, 2, 5, 22, 2, 4, 13, -16, 3], [-2, -2, -3, 7, 6, 2, 9, -11, -7, 2, -6, -3], [24, 2, 5, 4, -2, -2, 14, -2, 0, 11, -11, -1], [-3, 1, -10, -3, -1, 3, -17, 1, -3, -6, 1, -9], [10, -6, 4, -3, 0, 0, 10, -5, -10, 17, -7, -1], [-12, 3, -16, -5, -2, 3, -10, -1, -1, -6, 4, -8], [10, -4, -12, 9, 5, 3, -9, -7, -16, -4, -4, -1], [11, -1, 0, -4, -13, 3, -14, 2, -3, -4, 8, -2], [-5, -5, -4, 4, -8, 6, 1, -9, 2, 15, -4, -11], [6, 10, 8, -2, -15, -22, 2, -6, -6, 11, -13, -5], [-4, 7, -1, -3, -1, 8, -8, -2, -3, 0, -6, -8], [-6, 3, 6, 0, -17, -9, -6, -8, 12, 8, -12, -3], [-13, 21, -9, 0, 6, 9, 12, 10, 4, 12, -1, 0], [-10, -2, -5, -12, -10, -6, -15, -14, -6, 4, -10, -8], [3, -11, 3, 3, 3, 8, 12, 6, 3, -3, 6, 16], [-3, -4, -4, 10, 19, -2, 17, 5, 1, 4, 1, 7], [-6, 11, -2, -3, 10, -1, 14, 9, 2, -9, 1, 2], [12, 6, -5, 3, -4, -10, -1, 10, 4, -4, 1, 11], [15, 3, 2, -5, -16, -16, -5, 4, 11, 3, -3, 0], [-15, 10, -2, 6, 3, 8, 25, -1, -4, 10, -9, 0], [-6, -2, 2, 1, -5, -5, -7, 0, 18, -2, -1, -5], [3, 4, 3, 14, 22, 16, 25, 12, -1, -4, 23, 13], [-2, 12, 6, 9, 20, 17, 14, 4, -9, 5, 11, 13], [22, -9, 8, 2, 8, -7, -5, 6, 7, -5, 13, 10], [13, 2, -2, 0, -5, -15, -11, 1, -2, 3, -4, -6], [6, -2, 2, -1, -12, 3, -13, -5, 2, -9, 0, 0], [-12, 15, -1, -10, -14, 2, -8, -9, 10, 7, -13, 0], [-10, 4, 2, -9, -20, -12, -9, -3, 2, -1, -1, 4], [13, -11, 4, 0, -10, -10, -2, 18, 11, -8, 11, 3], [9, -3, -10, 10, 5, 4, -6, 7, -11, -7, 2, -6], [3, 0, -4, 5, 6, 12, 6, 9, 2, 0, 9, 5], [14, -15, 3, -5, 9, 2, -12, 2, 7, -10, 8, 13], [-4, -3, 1, -13, -10, 5, -7, -6, 5, -9, -5, 5], [23, -20, 3, -1, 0, 0, -3, -1, 1, -5, 2, 4], [10, -10, -7, 7, 10, 1, 2, 8, -1, -2, 8, -6], [-14, -4, -13, 2, 16, 14, 2, 0, -2, -1, -1, -11], [2, -9, -3, 18, 18, 13, 18, 7, 0, 2, 8, 0], [10, 11, -9, 12, 18, 21, 15, 7, -1, -1, 12, 3], [-15, 0, -5, -4, 1, 0, -20, -9, 1, 0, 0, 0], [-6, -3, 0, -7, 2, 0, -8, -3, 2, -4, -12, -1], [14, 12, -2, 3, 1, -3, 14, 4, 0, -2, 3, 0], [-7, 5, 3, -8, 4, -13, 12, -2, -6, -1, -2, 0], [36, -13, 0, 4, -14, -8, -3, -3, -4, -4, -2, -2], [25, 2, -4, -6, 0, 2, -13, 3, 1, -11, 11, -4], [-18, -9, -7, 5, -3, 4, -2, -1, 3, -6, 8, 3], [17, 2, -2, -1, 0, 2, -6, 2, 10, -8, 12, -2], [-1, 5, -2, 9, -4, 10, -1, -3, -12, 7, -4, -9], [2, 3, -7, 8, 11, 21, 17, 2, 0, 17, -1, -1], [9, -12, 0, -7, -8, -1, -12, -6, 4, -20, 1, 7], [1, -4, -4, 0, 0, 8, 0, -2, 0, 9, -2, -8], [-10, -4, -3, 2, 16, 3, 6, -4, -3, -8, 10, -4], [-4, 10, -4, 0, -10, -9, 2, -2, -11, 2, -10, -16], [-16, 15, -5, 8, 19, 14, 8, 0, 1, 10, 0, 1], [0, 15, 4, 0, -17, -14, 6, 2, 8, 6, -15, -15], [2, 16, 5, 17, 19, 22, 20, -3, -9, 5, 3, 4], [-13, -1, 14, -11, -11, 6, -3, -6, -3, 7, -9, 9], [8, 15, -1, 11, 17, 20, 18, 3, -3, 3, 13, 6], [-14, 8, -1, -6, 7, 9, -1, 9, -2, -6, 7, 0], [-15, 2, -8, 7, 28, 18, 3, -4, -8, 1, 12, 2], [-1, 2, -9, 4, 17, -11, 3, 7, 3, -8, 9, 5], [-8, 11, 10, 1, 0, -7, 12, 2, 11, 8, 0, 5], [15, -11, -8, 4, 0, -4, -5, -1, -6, -9, 10, -5], [10, 7, -3, 6, -3, 18, 2, 5, 9, 1, 7, -1], [-25, 18, 0, 12, 13, 26, 21, 4, -1, 16, 0, 5], [8, -1, 13, -9, -8, -12, -4, -4, 2, 0, 4, 12], [9, -3, 7, 9, 6, 15, -1, -7, 5, 7, 0, 4], [-4, -4, 2, -14, -14, -2, 3, -6, 1, 5, -14, -2], [-5, 5, 1, 5, 3, 6, 18, 3, 0, -4, -1, -4], [1, -2, 6, -7, -10, -3, -9, 8, 0, 5, 6, -5], [0, 15, 1, 9, 5, 11, 1, 4, -5, 6, -1, 6], [13, -7, 16, 8, -10, -5, 10, -1, 5, 8, 3, 10], [17, 8, 2, 5, -3, -13, -2, -9, -3, 2, -13, -10], [-10, -7, 2, 0, 3, 0, 5, 4, -3, 8, -3, -3], [-3, -8, -4, 10, 5, 6, 8, 2, -5, -1, 0, 1], [-6, 2, 7, 6, -5, 6, 20, 7, 10, 24, -2, 10], [-8, 12, -4, 15, 15, 22, 12, 7, -2, 11, 1, -3], [-7, 6, 12, -12, -11, -14, -8, -1, 8, 7, 0, 2], [-1, 5, 2, 4, -11, 0, 8, 8, -3, 13, -5, -3], [-10, 16, -5, -3, 5, 2, 20, 7, -3, -4, -10, 5], [21, 0, 3, 2, 2, -7, 12, -1, -12, 9, -15, -2], [16, -20, -6, -3, 8, 6, -16, -3, -10, -13, 17, -7], [-4, -7, 8, -3, -19, -5, -18, -12, -2, 0, -2, -9], [3, -3, 4, 9, 15, 3, 21, 4, -1, 12, -9, 6], [-8, -4, 5, -6, 3, -5, -17, -14, 12, -6, 6, -3], [-14, 1, -12, 6, 9, 3, -10, 4, 3, -2, 8, -2], [-1, 18, 11, 1, -4, -16, 11, -7, 5, 11, -16, 3], [25, 0, 11, -15, -9, -5, -2, 11, 14, -8, 1, 11], [-18, -15, -5, -1, 15, 7, -6, -8, -15, -3, 5, -5], [2, -4, -1, -6, -9, -19, -6, -7, -6, 3, -15, -6], [2, 0, -8, 5, 2, 1, -3, 9, 14, -2, 12, 0], [18, -4, 8, 8, -4, -2, 0, -3, -2, 11, -3, -2], [11, -3, -4, -9, -5, -8, -16, -9, 4, -11, -12, -10], [-19, 5, -1, 6, 15, 8, 2, 4, -6, 11, 2, -13], [-7, -11, -7, 6, 14, 6, 2, 19, 10, -7, 22, 7], [-8, 5, 2, 6, 12, 12, 4, 8, -4, -5, 21, 8], [2, -2, 13, 1, -10, -1, 11, -2, 1, 12, -2, 0], [-9, -3, 2, -12, -8, 11, -12, 3, 5, -7, 10, 0], [7, -13, -5, 0, 4, 6, -4, 2, -14, -1, 10, 0], [28, -1, 11, -7, -22, -13, -13, -8, 9, 7, -7, 3], [9, 2, -12, 7, -2, 1, 3, -9, -10, 9, -16, -20], [7, 1, 9, -6, -4, 0, 5, -3, -1, -8, -1, 14], [-10, -1, 3, 1, -8, -10, 8, 9, 10, 5, 9, 7], [11, 2, -4, -11, -13, -11, -11, -4, 1, 6, -13, -18], [1, 1, 6, -6, -14, -11, 5, -18, 6, 9, -8, -1], [-5, 0, -7, -1, 3, 13, 12, -10, -6, -4, 5, 1], [0, -13, -8, 12, 5, 0, -15, 9, 3, -6, 6, -4], [-11, 7, 18, 1, -1, 21, 2, -1, 2, 10, -3, 15], [25, -18, 10, 1, 0, 6, -7, 1, 13, -10, 3, 11], [9, 6, 13, 1, -4, 7, 20, 4, -11, 2, -18, 7], [5, -2, -7, 2, -4, -4, -14, -5, 0, -8, 8, 2], [5, 7, -13, -1, -7, -11, -7, -4, 0, 5, 4, -18], [-15, 11, -3, 3, 9, -1, 23, -14, -16, 8, -19, -12], [-14, -3, 8, 5, 1, 5, 5, 1, 11, 6, 8, 1], [31, 18, 10, 0, -7, -1, 16, 4, -4, 6, -17, 10], [31, -9, 3, -2, -1, -6, -22, 3, 1, 0, -1, 0], [-13, -4, 2, 3, 9, 7, 15, 5, -6, 5, -8, 1], [24, -16, -4, -2, -5, -12, -31, -1, 16, -13, 11, 2], [-24, 4, -5, -3, 10, 9, 8, 1, 1, -4, 2, 4], [-22, -21, -5, 9, -10, 6, -8, 10, 11, -2, 4, -3], [-19, 18, 8, 1, 10, 15, 12, 12, 1, 12, -3, 11], [-20, 20, -1, 2, -1, 7, 10, -2, -7, 10, -24, -5], [23, -12, -8, 2, 22, 10, 4, 2, -2, -11, 18, 5], [17, -23, -9, 5, -17, -11, -15, -11, -9, -10, 2, -13], [2, 12, -1, -3, 21, 15, 16, -10, -9, 12, -4, 0], [-11, -4, -15, 16, -1, 14, 8, 3, 0, 6, 1, -9], [18, -18, -5, -13, -12, -18, -27, -13, 0, -10, -8, -7], [-7, 5, -3, 4, 23, 11, 15, 5, -2, 4, 4, 0], [-2, -9, -1, 10, 7, 6, -8, -3, -4, -6, 3, 0], [7, 2, 2, 14, 5, -5, 10, 4, -22, 0, -3, -1], [19, -15, -1, 8, -6, -1, 3, -3, 1, 4, -10, -8], [-4, 13, -3, -8, -17, -21, -1, 8, 3, 4, -16, -4], [14, -10, 19, -4, -5, -4, 2, -8, -1, -3, -3, 11], [-36, 1, -1, -4, 10, -1, 9, -2, 9, -3, -3, 13], [-7, 10, -4, 8, 8, 10, 32, 3, -5, 8, -9, 7], [-31, 14, 13, -3, 1, 1, 0, -1, 19, 10, -1, -4], [-10, 4, -7, 13, 9, 11, 3, 5, -15, -12, 13, 7], [9, -15, 5, -18, -18, -26, -25, -14, 6, -8, -5, -8], [25, -7, 13, -6, -10, -3, -16, 0, 14, -12, 9, 23], [-19, 1, -21, 4, 19, 15, 6, -4, -17, 0, 11, -7], [28, -5, -11, 1, -1, -9, 4, 0, -17, -4, -5, -3], [8, 0, -19, -6, 2, 3, -17, 5, 10, -8, 8, -10], [5, -17, 2, 1, 10, 8, -21, 1, 0, -8, 17, 10], [5, -4, 8, 2, 11, 9, 3, 13, 7, -18, 19, 18], [13, -18, -1, -8, -7, 9, -9, -4, -17, -18, 4, 9], [-18, 17, 0, -5, -4, -12, 1, 6, 3, 11, -17, -9], [-15, -10, 2, 4, -5, 22, -5, -5, -6, -6, 3, 2], [13, -4, 2, 3, 11, 12, -8, -6, -7, -5, 8, 4], [17, -3, -6, -8, -10, 4, -19, -26, -5, -8, -9, -14], [29, 1, 5, 4, -15, -1, 12, -10, -15, 12, -23, -2], [5, 0, -3, 11, 5, 16, 3, 0, 2, 4, 5, -1], [-1, 1, 1, 3, -4, 20, -2, 9, 15, 8, 9, 7], [9, -12, -6, -15, -14, -1, -26, -12, -8, -11, 1, -10], [4, 0, -6, 13, 20, -7, 23, 8, -3, 2, 9, 11], [-26, 14, -5, -3, 2, 2, 11, 7, 12, 6, 4, 0], [2, -23, -4, 3, -15, -3, 1, 8, 16, -1, -2, 12], [11, 4, 4, -1, -12, -5, 23, -6, 15, 12, -13, 3], [21, 7, -13, 16, 24, 2, 23, 7, -17, 3, 12, -3], [-18, 10, 7, -5, -2, -20, -4, 14, 15, 1, 5, 3], [-24, 9, -2, -3, 18, 22, 18, 4, -10, 7, 3, 5], [-3, 11, -2, -12, -8, -9, -2, 0, -1, 2, -4, -5], [29, -16, -8, 6, 3, 7, 4, 13, 10, -21, 20, 6], [-29, 21, -4, -5, 14, 31, 15, 6, 3, 7, 12, 9], [-24, 10, 2, 3, 5, -9, 5, 19, 20, -2, 4, 5], [-6, -6, -14, 7, 20, 14, -8, 13, -6, -3, 13, -9], [-14, 30, -4, 7, 16, 9, 17, 5, 8, -5, 11, 0], [-3, 1, 12, 4, 0, 20, 6, -9, 11, 13, 2, 15], [-4, 17, -12, 2, 13, 14, 3, -1, -14, -14, -2, -4], [3, 19, 6, 5, 8, 9, 11, 2, 7, 4, -7, 2], [30, 1, -8, 8, 5, 6, -10, 8, -5, -7, 9, -8], [6, -24, 7, -4, -5, 3, 5, -12, -2, -4, -8, 5], [19, -5, 1, -3, 4, 17, -10, -20, -19, 3, -14, -10], [-12, -12, 0, -5, -11, 4, -4, -15, -1, 2, -14, 0], [6, -8, 4, -3, -10, -12, 3, -9, -1, 16, -5, -10], [-9, 13, -5, 13, 20, 12, 16, 9, -5, 5, 17, -1], [1, -4, 1, 3, -1, 19, 7, -2, 11, 7, -2, 8], [28, -7, 3, -4, 3, -8, -2, 18, 0, -10, 8, 3], [8, -5, 7, -16, -22, -20, -26, -6, 15, 0, 4, 0], [5, -2, 7, 5, -11, -13, 8, 5, 2, 7, -6, 5]]
